@@ -20,7 +20,7 @@
 
 $this->messages=array
   (
-   "about"=>"<a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> par <a href=\"mailto:ufoot@ufoot.org\">U-Foot</a>",
+   "about"=>"<a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> version %s par <a href=\"mailto:ufoot@ufoot.org\">U-Foot</a>",
 
    "title"=>"Titre",
    "text"=>"Texte",
@@ -66,7 +66,7 @@ $this->messages=array
    "rights_3"=>"Document confidentiel.",
    "meta_description"=>"%s (pas de description d&eacute;taill&eacute;e)",
    "meta_copyright"=>"Copyleft &copy; %s %s",
-   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> le %s.",
+   "page_generated_by_uwikicms"=>"Page g&eacute;n&eacute;r&eacute;e par <a href=\"http://www.ufoot.org/uwikicms\">UWiKiCMS</a> (v%s) le %s.",
    "last_update"=>"Mis &agrave; jour le %s.",
    "source"=>"Source&nbsp;:",
    "action_root"=>"Accueil",
@@ -116,7 +116,8 @@ $this->messages=array
    "allinone_status"=>"N'afficher que les documents dans cet &eacute;tat",
    "allinone_max_size"=>"Taille max des images (en pixels)",
    "gallery_title"=>"Diaporama XUL",
-   "gallery_back"=>"Retour au site HTML",
+   "gallery_prev"=>"Image prcdente",
+   "gallery_next"=>"Image suivante",
    "gallery_empty"=>"Aucune image dans ce diaporama",
 
    ""=>""
