@@ -618,6 +618,11 @@ class UWC_Page {
     return $this->conf->htprefix.$this->conf->images_dir;
   }
 
+  function get_js_dir() {
+    // we don't use make_url here since we don't want any parameter
+    return $this->conf->htprefix."/_uwikicms/template/js";
+  }
+
   function make_url_no_esc($path,$params=false) {
     if (!$path) {
       /*
