@@ -68,7 +68,7 @@
 
   <div id="infos" class="box system">
     <div id="credits">
-    <? echo $this->translate1("page_generated_by_uwikicms", $this->today()); ?>
+    <? echo $this->translate2("page_generated_by_uwikicms", $this->conf->version,$this->today()); ?>
     </div>
     <? if ($this->need_rights()) { ?>
     <div id="rights">
